==> jaguar_mongo_data_store-0.0.1.tar.gz: lib/src/mongo_data_store.dart <==
library mongo_data_store.adapter;

import 'dart:async';
import 'package:mongo_dart/mongo_dart.dart' as mgo;
import 'package:jaguar_data_store/jaguar_data_store.dart';
import 'package:jaguar_serializer/serializer.dart';

abstract class Idied {
  String id;
}

class MongoDataStore<ModelType extends Idied>
    extends DataStore<ModelType, String> {
  final String collectionName;

  final MapSerializer<ModelType> serializer;

  final mgo.Db db;

  final mgo.DbCollection collection;

  MongoDataStore(this.serializer, this.collectionName, this.db)
      : collection = db.collection(collectionName);

  mgo.SelectorBuilder get _w => mgo.where;

  mgo.ObjectId _toOId(String id) => mgo.ObjectId.parse(id);

  mgo.SelectorBuilder _wId(String id) => _w.id(_toOId(id));

  Stream<ModelType> getAll() =>
      collection.find().map((Map doc) => serializer.fromMap(doc));

  Future<ModelType> getById(String id) async {
    final Map doc = await collection.findOne(_wId(id));
    return serializer.fromMap(doc);
  }

  Future<String> insert(ModelType object) async {
    final String id = new mgo.ObjectId().toHexString();
    object.id = id;
    await collection.insert(serializer.toMap(object),
        writeConcern: mgo.WriteConcern.ACKNOWLEDGED);
    return id;
  }

  Future<Null> updateById(String id, ModelType object) =>
      collection.update(_wId(id), serializer.toMap(object),
          writeConcern: mgo.WriteConcern.ACKNOWLEDGED);

  Future<Null> deleteById(String id) =>
      collection.remove(_wId(id), mgo.WriteConcern.ACKNOWLEDGED);
}

==> jaguar_mongo_data_store-0.0.3.tar.gz: lib/src/mongo_data_store.dart <==
library mongo_data_store.adapter;

import 'dart:async';
import 'package:mongo_dart/mongo_dart.dart' as mgo;
import 'package:jaguar_data_store/jaguar_data_store.dart';
import 'package:jaguar_serializer/serializer.dart';

abstract class Idied {
  String id;
}

class MongoDataStore<ModelType extends Idied>
    extends DataStore<ModelType, String> {
  final String collectionName;

  final MapSerializer<ModelType> serializer;

  final mgo.Db db;

  final mgo.DbCollection collection;

  final mgo.WriteConcern writeConcern;

  MongoDataStore(this.serializer, this.collectionName, this.db,
      {this.writeConcern: mgo.WriteConcern.ACKNOWLEDGED})
      : collection = db.collection(collectionName);

  mgo.SelectorBuilder get _w => mgo.where;

  mgo.ObjectId _toOId(String id) => mgo.ObjectId.parse(id);

  mgo.SelectorBuilder _wId(String id) => _w.id(_toOId(id));

  Stream<ModelType> getAll() =>
      collection.find().map((Map doc) => serializer.fromMap(doc));

  Future<ModelType> getById(String id) async {
    final Map doc = await collection.findOne(_wId(id));
    return serializer.fromMap(doc);
  }

  Future<String> insert(ModelType object) async {
    final String id = new mgo.ObjectId().toHexString();
    object.id = id;
    await collection.insert(serializer.toMap(object),
        writeConcern: writeConcern);
    return id;
  }

  Future<Null> updateById(String id, ModelType object) => collection
      .update(_wId(id), serializer.toMap(object), writeConcern: writeConcern);

  Future<Null> deleteById(String id) =>
      collection.remove(_wId(id), writeConcern);

  Future<Null> deleteAll() => collection.remove();
}
